function[Ncl,Nray,AoA_mu,AoA_std,AoD_mu,AoD_std,DS_mu,DS_std,rD,K_mu,K_std,SF_std,C1,cASA,cASD]=ChannelParameters(scenario,LOS)

% This Matlab function generates the IMT-Advanced channel parameters considered in
%
% Zehra Yigit-Ertugrul Basar-Ibrahim Altunbas "SimMBM Channel Simulator for Media-Based Modulation Systems"
% 
%  Some of the values used here are in Table I in the paper above
%
% Input Parameters
% - scenario==1  ==> 'Indoor Hotspot (InH)'
% - scenario==2  ==> 'Urban Micro (UMi)'
% - scenario==3  ==> 'Urban Macro (UMa)'
% - LOS  ==> ' a variable  that indicates the absence (0) or presence (1) of LOS between the transmitter
% and the receiver
%
% Output Parameters
% - Ncl: 'Number of cluster in the specified environment'
% - Nray: 'Number of scatterers within each cluster'
% - DS_std: 'std of delay spread '
% - DS_mu: 'mean of delay spread '
% - SF_std: 'Shadowing std'
% - AoA_std: 'std of Angle of Arrival spread '
% - AoA_mu: 'mean of Angle of Arrival spread '
% - AoD_std: 'std of Angle of Departure spread '
% - AoD_mu: 'mean of Angle of Departure spread '
% - K_std: 'std of Ricean K '
% - K_mu: 'mean of Ricean K '
% - C1: 'scaling parameter related to total number of clusters'
% - cASD: 'cluster departure arrival spread'
% - cASA: 'cluster angular arrival spread'
%

 if scenario==1  %Indoor Hotspot
 
if LOS==1
 
   Ncl=15;
   Nray=20;
   AoA_mu=(1.62);
   AoA_std=(0.22);  
   AoD_mu=(1.60);
   AoD_std=(0.18);  
   DS_std=(0.18);  % 
   DS_mu=-7.70;
   rD=3.6;
   K_std=4; %Rician K factor 
   K_mu=7;
   SF_std=3; %dB
   C1=1.434;
  cASA=8;
  cASD=5;

else 
   
    Ncl=19;
    Nray=20;
    AoA_mu=(1.77);  % in radian
    AoA_std=(0.16);  % in radian
   AoD_mu=(1.62);  % in radian
   AoD_std=(0.25);  % in radian
   DS_std=(0.14);  % in sec
   DS_mu=(-7.41);  % in sec
   rD=3;
   SF_std=4;
   K_std=NaN; %Rician K factor 
   K_mu=NaN;
   C1=1.501;
  
  cASA=11;
  cASD=5;
  
 
end


elseif scenario==2  %Urban Micro
   
if LOS==1
  
   Ncl=12;
   Nray=20;
   AoA_mu=((1.75));  % in 
   AoA_std=((0.19));  % in radian
   AoD_mu=((1.20));  % in radian
   AoD_std=((0.43));  % in radian
   DS_std=(0.40);  % 
   DS_mu=-7.19;
   rD=3.2;
   K_std=5; %Rician K factor 
   K_mu=9;
   SF_std=3; %dB
   C1=1.146;
  cASA=17;
  cASD=3;
  
  
else 
    Ncl=19;
    Nray=20;
    AoA_mu=((1.84));  % in radian
    AoA_std=((0.15));  % in radian
    AoD_mu=((1.41));  % in radian
    AoD_std=((0.17));  % in radian
   DS_std=(0.54);  % 
   DS_mu=-6.89;
   rD=3;
   K_std=NaN; %Rician K factor 
   K_mu=NaN;
   SF_std=4; %dB 
   C1=1.501;
   
  cASA=22;
  cASD=10;
   
   

end

elseif scenario==3 %Urban Macro
  
   Ncl=12;
   Nray=20;
   AoA_mu=((1.81));  % in radian
   AoA_std=((0.20));  % in radian
   AoD_mu=((1.41));  % in radian
   AoD_std=((0.28));  % in radian
   DS_std=(0.66);  % 
   DS_mu=-7.03;
   rD=2.5;
   K_std=3.5; %Rician K factor 
   K_mu=9;
   SF_std=4; %dB
   C1=1.146;
  cASA=11;
  cASD=5;
  
  

end

end