
function[DS,SF,ASA,ASD,K]=LargeScale(scenario, LOS,DS_std, DS_mu,SF_std,AoA_std,...
    AoA_mu,AoD_std,AoD_mu,K_std,K_mu)

% This Matlab function generates large scale parameters  of  the IMT-Advanced channels considered in
%
% Zehra Yigit-Ertugrul Basar-Ibrahim Altunbas "SimMBM Channel Simulator for Media-Based Modulation Systems"
%
%
% Input Parameters
% - scenario==1  ==> 'Indoor Hotspot (InH)'
% - scenario==2  ==> 'Urban Micro (UMi)'
% - scenario==3  ==> 'Urban Macro (UMa)'
% - LOS  ==> ' a variable  that indicates the absence (0) or presence (1) of LOS between the transmitter
% - DS_std: 'std of delay spread '
% - DS_mu: 'mean of delay spread '
% - SF_std: 'Shadowing std'
% - AoA_std: 'std of Angle of Arrival spread '
% - AoA_mu: 'mean of Angle of Arrival spread '
% - AoD_std: 'std of Angle of Departure spread '
% - AoD_mu: 'mean of Angle of Departure spread '
% - K_std: 'std of Ricean K '
% - K_mu: 'mean of Ricean K '
%
% Output Parameters
% - DS  ==> 'Delay Spread'
% - SF  ==> 'Shadowing Fading'
% - ASA  ==> 'Angle of Arrival Spread'
% - ASD  ==> 'Angle of Departure Spread'
% - K  ==> 'Rician K factor'


  
  
  %CorrelationMatrix=  [   1        rDS_SF    rDS_ASA    rDS_ASD    rDS_K                       
  %                      rDS_SF       1       rSF_ASA    rSF_ASD    rSF_K 
  %                      rDS_ASA    rASA_SF      1       rASA_ASD   rASA_K
  %                      rDS_ASD    rASD_SF   rADS_ASA      1       rASD_K
  %                      rDS_K      rK_SF     rK_ASA     rK_ASD        1   ];

if scenario==1  %Indoor Hotspot

if LOS==1
   
  
CorrelationMatrix=[1     -0.8    0.8    0.6   -0.5
                  -0.8     1    -0.5   -0.4    0.5
                   0.8   -0.5     1     0.4     0
                   0.6   -0.4    0.4     1      0
                  -0.5    0.5     0      0      1];     
   
  
else 
    
CorrelationMatrix=[ 1    -0.5     0    0.4
                   -0.5     1    -0.4    0
                     0    -0.4     1     0
                    0.4     0      0     1];
%    
    
end


elseif scenario==2  %Urban Micro
   

if LOS==1
 
   
  CorrelationMatrix=[1     -0.4    0.8    0.5   -0.7
                    -0.4     1    -0.4   -0.5    0.5
                     0.8   -0.4     1     0.4   -0.3
                     0.5   -0.5    0.4     1    -0.2
                    -0.7    0.5   -0.3   -0.2     1  ];
   
  
  
else 
  
   
  CorrelationMatrix=[1     -0.7    0.4    0
                    -0.7     1    -0.4    0
                     0.4   -0.4     1     0
                      0      0      0     1  ];
   

end

elseif scenario==3 %Urban Macro
    

   if LOS==1
  
  CorrelationMatrix=[1   -0.4   0.8   0.4  -0.4
                   -0.4    1   -0.5  -0.5    0
                   0.8   -0.5    1     0   -0.2
                   0.4   -0.5    0     1     0
                  -0.4     0   -0.2    0     1  ];

   end
end

[numRows,~] = size(CorrelationMatrix);
Ksi=randn(numRows,1); 

LSP=sqrt(abs(CorrelationMatrix))*Ksi;  

DS=10.^((LSP(1,:).*DS_std)+DS_mu);       %in sec
SF=10.^(0.1*(LSP(2,:).*SF_std));        %linear
ASA=min((10.^((LSP(3,:).*AoA_std)+AoA_mu)),104);    %in degrees
ASD=min((10.^((LSP(4,:).*AoD_std)+AoD_mu)),104);    %in degrees

if LOS==1
K=10.^(0.1*((LSP(5,:).*K_std)+K_mu));    %linear
else
K=0;
end

end