% This Matlab script can be used to generate IMT-Advanced-based Media-based Modulation (MBM) Channels at sub-6 GHz frequency band 
% Zehra Yigit-Ertugrul Basar-Ibrahim Altunbas "SimMBM Channel Simulator for Media-Based Modulation Systems"
% 
% Input Parameters
% - scenario==1  ==> 'Indoor Hotspot (InH)'
% - scenario==2  ==> 'Urban Micro (UMi)'
% - scenario==3  ==> 'Urban Macro (UMa)'
% - fc: 'Operating Frequency of Transmit Reconfigurable Antenna(s) (GHz)'
% - Tx: 'Number of Transmit Antennas'
% - Rx: 'Number of Received Antennas'
% - N:  'Number of Passive Reflecting Elements'
% - P:  'Number of States of Reconfigurable Antenna'
% - Tx_xy=[x_Tx,y_Tx] ==>      % 'Tx coordinates (in meters)'
% - Rx_xy=[x_Rx,y_Rx] ==>      % 'Rx coordinates (in meters)'
% - RIS_xy=[x_RIS,y_RIS] ==> % 'RIS coordinates (in meters)'
%

delete(gcp('nocreate'))
clear all; close all; clc;

scenario=1;  
Tx=1;  
Rx=1;
N=64; %number of reflectors at the RIS
m=Tx*log2(4);
c=3e8;   % the speed of light 
fc=2.45; %GHz
lambda=c/(fc*10^9);   % wavelength
kappa=2*pi/lambda;
da=lambda/2; % distance between  two adjacent antennas (ULA)
dr=lambda/2; % distance between  two RIS Reflectors (ULA)

% Recommended locations for Outdoor (UMi, UMa) Environments

% Tx_xy=[45,15,0];       % Tx coordinates (in meters)
% Rx_xy=[125,130,0];   % Rx coordinates (in meters)
% RIS_xy=[48,18,0];

% Recommended locations for Indoor Hotspot
 Tx_xy=[30,10,0];       % Tx coordinates (in meters)
 Rx_xy=[55,35,0];       % Rx coordinates (in meters)
 RIS_xy=[33,13,0];

x_Tx=Tx_xy(1); y_Tx=Tx_xy(2); 
x_Rx=Rx_xy(1); y_Rx=Rx_xy(2); 
x_RIS=RIS_xy(1); y_RIS=RIS_xy(2); 

d1=norm(Tx_xy-RIS_xy); % distance d (in meters)
d2=norm(RIS_xy-Rx_xy); % distance d (in meters)
d3=norm(Tx_xy-Rx_xy); % distance d (in meters)


% Reconfigurable antenna gain parameters

P=4;% number of RA states
data=48;% data length of considered RA parameters 
AnglePattern=zeros(data,P);  
GainPattern=zeros(data,P);

ReadPattern=xlsread('RA_patterns_2_45GHz.xlsx');

for p=1:P
    AnglePattern(:,p)=ReadPattern(:,2*p);
    
   GainPattern(:,p)=10.^(ReadPattern(:,2*p-1)./10);
   AnglePattern(:,p)=wrapTo180( AnglePattern(:,p));
  
end
%

uk=rand(1,m)>0.5;
     

Tx_bits=uk(1:m);
Tx_bits=reshape(Tx_bits,log2(4),Tx);
Tx_l=zeros(1,Tx);

% index of the active RA state

for t=1:Tx
    Tx_inx=num2str(Tx_bits(:,t)).';
    Tx_inx(isspace(Tx_inx))='';
    Tx_l(t)=1+bin2dec(Tx_inx)+(t-1)*P;
    
end

Pattern1=P*Tx;

% Generate  T-RIS Channel
% T-RIS link experiences pure LOS
% LOS==1
d=d1;  %T-RIS distance
LOS_T_RIS=1;
PL_T_RIS=PathLoss(d,fc,scenario,LOS_T_RIS);

%LOS direction
I_phi0=sign(x_RIS-x_Tx);
phi_RIS_LOS = I_phi0* atand ( abs( x_RIS-x_Tx) / abs(y_RIS-y_Tx) );
  %phi_Tx_LOS=-phi_RIS_LOS;
   
I_phi_Tx=sign(x_Tx-x_RIS);
phi_Tx_LOS = I_phi_Tx* atand ( abs( x_Tx-x_RIS) / abs(y_Tx-y_RIS) );

% Pure LOS channel matrix of T-R link
 hLOS=zeros(N,P*Tx);
    for a1=1:P*Tx
       for a2=1:N
  pt1=mod(a1-1,P)+1;
  r1=fix((a1-1)/P)+1;
 [valx,inx]=min(abs(phi_Tx_LOS-AnglePattern(:,pt1)));
   GainTx_LOS=GainPattern(inx,pt1);
   GainRIS=pi;
   
   hLOS(a2,a1)=(sqrt(GainTx_LOS*GainRIS*PL_T_RIS).*exp(1i*kappa*da*(r1-1).*sind(phi_Tx_LOS)).*exp(1i*kappa*dr*(a2-1)*sind(phi_RIS_LOS)));  
        end
     end

hk=hLOS*exp(1i*rand*2*pi);

% Generate  R-RIS Channel
% R-RIS link experiences multi-path propagation

% Calculate LOS probability and indicate LOS between R-RIS link
LOS_R_RIS=LOS_Probability(d2,scenario);

% Path loss evaluation of R-RIS link
PL_R_RIS=PathLoss(d2,fc,scenario,LOS_R_RIS);

% LOS direction of R-RIS link
I_phi0=sign(x_Rx-x_RIS);
phi_RIS_R_LOS = I_phi0* atand ( abs( x_Rx-x_RIS) / abs(y_Rx-y_RIS) );
   
I_phi1=sign(x_RIS-x_Rx);
phi_R_RIS_LOS = I_phi1* atand ( abs( x_RIS-x_Rx) / abs(y_RIS-y_Rx) );

% Determine Channel Parameters  for the specified environment
[Ncl_R_RIS,Nray_R_RIS,AoA_mu_1,AoA_std_1,AoD_mu_1,AoD_std_1,DS_mu_1,DS_std_1,rD_1,K_mu_1,K_std_1,SF_std_1,C1_1,cASA_1,cASD_1]=ChannelParameters(scenario,LOS_R_RIS);

% Generates Large Scale Parameters
[DS_1,SF_1,ASA_1,ASD_1,K_1]=LargeScale(scenario, LOS_R_RIS,DS_std_1, DS_mu_1,SF_std_1,AoA_std_1,AoA_mu_1,AoD_std_1,AoD_mu_1,K_std_1,K_mu_1);

% Determine departure angles in direction of R
[AoD_R_RIS,Pnm_R_RIS]=MultiPathFading(rD_1,DS_1,SF_std_1,K_1,Ncl_R_RIS,Nray_R_RIS,C1_1,scenario,LOS_R_RIS,ASD_1,phi_RIS_R_LOS,cASD_1, N);

%wraps RIS departure angles into [-90,90] degrees
AoD_R_RIS=mod(AoD_R_RIS+90,180)-90;

% Determine arrival angles in direction of R
[AoA_R_RIS]=MultiPathFading(rD_1,DS_1,SF_std_1,K_1,Ncl_R_RIS,Nray_R_RIS,C1_1,scenario,LOS_R_RIS,ASD_1,phi_R_RIS_LOS,cASA_1, Rx);

% generates R-RIS Channel matrix

g=zeros(Rx,N);
gLOS=zeros(Rx,N);
counter=1;

alpha_R_RIS=(sqrt(Pnm_R_RIS).*(randn(1,Ncl_R_RIS*Nray_R_RIS)+1i*randn(1,Ncl_R_RIS*Nray_R_RIS)))./sqrt(2);
for a1=1:Rx
    for a2=1:N
       

Arrival_R_RIS=AoA_R_RIS(a1,:);
GainRx=1;

% RIS

Departure_R_RIS=AoD_R_RIS((a2),:);

GainRIS=pi;

g(a1,a2)=sum(alpha_R_RIS.*sqrt(GainRx.*GainRIS.*PL_R_RIS).*exp(1i*kappa*da*(a1-1).*sind(Arrival_R_RIS)).*exp(1i*kappa*dr*((a2-1)*sind(Departure_R_RIS))));



counter=counter+1;
 
     end
end

if LOS_R_RIS==1
 

    for a1=1:Rx
       for a2=1:N
   
   GainRIS=pi;
   
    gLOS(a1,a2)=(sqrt(GainRx*GainRIS*PL_R_RIS).*exp(1i*kappa*da*(a1-1).*sind(phi_R_RIS_LOS)).*exp(1i*kappa*dr*(a2-1)*sind(phi_RIS_R_LOS)));  
        end
     end
 else
    gLOS=0;
end

gk=g*exp(1i*rand*2*pi)+gLOS*exp(1i*rand*2*pi);

% Generate  T-R Direct Link
% T-R link experiences multi-path propagation

% Calculate LOS probability and indicate LOS between T-R link
LOS_T_R=LOS_Probability(d3,scenario);

% Path attenuation in T-R link
PL_T_R=PathLoss(d3,fc,scenario,LOS_T_R);

% LOS direction of T-R link
I_phi2=sign(x_Rx-x_Tx);
phi_T_R_LOS = I_phi2* atand ( abs( x_Rx-x_Tx) / abs(y_Rx-y_Tx) );

I_phi3=sign(x_Tx-x_Rx);
phi_R_T_LOS = I_phi3* atand ( abs( x_Tx-x_Rx) / abs(y_Tx-y_Rx) );


% Generates channel parameters of T-R
[Ncl_T_R,Nray_T_R,AoA_mu_2,AoA_std_2,AoD_mu_2,AoD_std_2,DS_mu_2,DS_std_2,rD_2,K_mu_2,K_std_2,SF_std_2,C1_2,cASA_2,cASD_2]=ChannelParameters(scenario,LOS_T_R);

% Generates Large scale parameters of T-R
[DS_2,SF_2,ASA_2,ASD_2,K_2]=LargeScale(scenario, LOS_T_R,DS_std_2, DS_mu_2,SF_std_2,AoA_std_2,AoA_mu_2,AoD_std_2,AoD_mu_2,K_std_2,K_mu_2);

% Generates power  and  departure angle of each path
[AoD_T_R,Pnm_T_R]=MultiPathFading(rD_2,DS_2,SF_std_2,K_2,Ncl_T_R,Nray_T_R,C1_2,scenario,LOS_T_R,ASD_2,phi_T_R_LOS,cASD_2, P*Tx);

% Generates arrival angle 
[AoA_T_R]=MultiPathFading(rD_2,DS_2,SF_std_2,K_2,Ncl_T_R,Nray_T_R,C1_2,scenario,LOS_T_R,ASD_2,phi_R_T_LOS,cASA_2, Rx);

% Generates T-R channel matrix for the indicated scenario

f=zeros(Rx,P*Tx);
f_LOS=zeros(Rx,P*Tx);

alpha_T_R=(sqrt(Pnm_T_R).*(randn(1,Ncl_T_R*Nray_T_R)+1i*randn(1,Ncl_T_R*Nray_T_R)))./sqrt(2);

counter=1;
for a1=1:P*Tx
    for a2=1:Rx
      
 %   Tx
pt1=mod(a1-1,P)+1;
r1=fix((a1-1)/P)+1;
Departure_T_R=AoD_T_R(a1,:);
TMP3 = bsxfun(@(v,t) abs(v-t), Departure_T_R(:), reshape(AnglePattern(:,pt1),1,[]));
[D3, idx3] = min(TMP3,[],2); 
phi_Tx3= AnglePattern(idx3,pt1).';
Gain_T_R=GainPattern(idx3,pt1).';
 
 
phi_Rx3=AoA_T_R(a2,:);
GainRx3=1;



f(a2,a1)=sum(alpha_T_R.*sqrt(Gain_T_R.*1.*PL_T_R).*exp(1i*kappa*da*(r1-1).*sind(phi_Tx3)).*exp(1i*kappa*da*((a2-1).*sind(phi_Rx3))));



counter=counter+1;
 

       % end
     end
end

if LOS_T_R==1
 

    for a1=1:P*Tx
       for a2=1:Rx
   
   pt1=mod(a1-1,P)+1;
  r1=fix((a1-1)/P)+1;
  [valx,inx]=min(abs(phi_T_R_LOS-AnglePattern(:,pt1)));
  Gain_T_R_LOS=GainPattern(inx,pt1);
  
    f_LOS(a2,a1)=(sqrt(Gain_T_R_LOS.*1*PL_T_R).*exp(1i*kappa*da*(r1-1).*sind(phi_T_R_LOS)).*exp(1i*kappa*da*(a2-1).*sind(phi_R_T_LOS)));  
        end
     end
 else
   f_LOS=0;
end


fk=f*exp(1i*rand*2*pi)+f_LOS*exp(1i*rand*2*pi);

H=hk(:,Tx_l);  % Overall T-RIS channel matrix corresponding to active RA state(s) 

F=fk(:,Tx_l); % Overall T-R channel matrix corresponding to active RA state(s) 

G=gk;   


if  Tx==1 && Rx==1        %SISO case
    Channel=abs(G)*abs(H)+F;
    
else                      %multi-antenna case
    D=eye(N);             %blind reflectors
    Channel=G*D*H+F; 
   
end


