function[Angle,Pnm]=MultiPathFading(rD,DS,X_sf,K,Ncl,Nray,C1,scenario,LOS,AS,phi_LOS,ClusterSpread, NumEl )

% This Matlab function generates multipath(small-scale) parameters  of  the IMT-Advanced channels considered in
%
% Zehra Yigit-Ertugrul Basar-Ibrahim Altunbas "SimMBM Channel Simulator for Media-Based Modulation Systems"
% 
%  Some of the values used here are in Table I in the paper above
%
% Input Parameters
% - scenario==1  ==> 'Indoor Hotspot (InH)'
% - scenario==2  ==> 'Urban Micro (UMi)'
% - scenario==3  ==> 'Urban Macro (UMa)'
% - rD: 'Delay distribution proportionality factor'
% - DS: 'Delay spread'
% - X_sf: 'Shadowing term (dB)'
% - K: 'Ricean K factor'
% - Ncl: 'Number of cluster in the specified environment'
% - Nray: 'Number of scatterers within each cluster'
% - C1: 'scaling parameter related to total number of clusters'
% - LOS  ==> ' a variable  that indicates the absence (0) or presence (1) of LOS between the transmitter
% and the receiver
% - AS: 'Angle spread (arrival ASA or departure (ASD))'
% - phi_LOS: 'LOS direction'
% - ClusterSpread: 'Cluster angle spread'
% - NumEl: 'Number of array elements (N, Rx, Tx)'
%
% Output Parameters
% - Angle  ==> 'Arrival/Departure angles corresponding to each path'
% - Pnm  ==> 'path power'
%%generate delays
Xn=rand(1,Ncl);
UnNormDelay=-rD*DS.*log(Xn);
Delay=sort(UnNormDelay-min(UnNormDelay),'descend');

%% generate powers
Zn=X_sf*randn(1,Ncl);
Power=exp(-Delay.*((rD-1)./(rD.*DS))).*(10.^(-Zn./10));

if LOS==1
    
 LOS_Power=K./(K+1);
 Pn=(1./(K+1)).*(Power./sum(Power));
 Power_Cl=Pn(1)+LOS_Power;
 Pn(1)=Power_Cl;

  C1=C1*(1.1035-0.028*(10*log10(K))-0.002*((10*log10(K)).^2)+0.0001*((10*log10(K)).^3));
else


  Pn=(Power/sum(Power));

   
 
end


Pnm=kron(Pn,ones(1,Nray))./Nray;

%% generate AoA/AoD for each R-RIS path
AS_rad=AS*pi/180;
% AoD
 if scenario==1
 Angle_1=-(AS_rad.*log(Pn/max(Pn)))./C1;  %Laplacian distribution
 else
 Angle_1=(2.*(AS_rad/1.4).*sqrt(-log(Pn/max(Pn))))./C1;   % Wrapped Gaussian
 end
 Angle_1=wrapToPi(Angle_1);
 
 Yn_AS=randn([1 Ncl]).*(AS_rad/7);
 AS_LOS=phi_LOS*pi/180;
 Angle_2=randsrc(1,Ncl).*Angle_1+Yn_AS;
    
 Angle_2=wrapToPi(Angle_2);
 
 if LOS==1
  Angle_3=(Angle_2)-(Angle_2(1)-AS_LOS);   
 else
  Angle_3=(Angle_2+AS_LOS);     
 end
   Angle_3= Angle_3*180/pi; %degree
   OffsetAngle=[0.0447,-0.0447,0.1413,-0.1413,0.2492,-0.2492,0.3715,-0.3715,0.5129,-0.5129,0.6797,-0.6797,...
                0.8844,-0.8844,1.1481,-1.1481,1.5195,-1.5195,2.1551,-2.1551];
       
Angle_4=kron(Angle_3,ones(NumEl,Nray))+ClusterSpread*kron(ones(NumEl,Ncl),OffsetAngle);
Angle=wrapTo180(Angle_4);
end 
